@@ -1,4 +1,4 @@
-//@line 39 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/browser/base/content/safeMode.js"
+//@line 39 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/browser/base/content/safeMode.js"
 
 function restartApp() {
   var appStartup = Components.classes["@mozilla.org/toolkit/app-startup;1"]
@@ -75,7 +75,7 @@ function onOK() {
   try {
     if (document.getElementById("resetUserPrefs").checked)
       clearAllPrefs();
-    if (document.getElementById("resetBookmarks").checked)
+    if (document.getElementById("deleteBookmarks").checked)
       restoreDefaultBookmarks();
     if (document.getElementById("resetToolbars").checked)
       deleteLocalstore();
@@ -103,7 +103,7 @@ function onLoad() {
 function UpdateOKButtonState() {
   document.documentElement.getButton("accept").disabled = 
     !document.getElementById("resetUserPrefs").checked &&
-    !document.getElementById("resetBookmarks").checked &&
+    !document.getElementById("deleteBookmarks").checked &&
     !document.getElementById("resetToolbars").checked &&
     !document.getElementById("disableAddons").checked &&
     !document.getElementById("restoreSearch").checked;
